'use client'
import { useEffect, useState } from "react";
import toast from 'react-hot-toast';
import { useOptionsConversation } from "@/feature/messenger/hooks/useOptionsConversation";
import useHandleConversationStore from "@/feature/messenger/store/useHandleConversationStore";
import { Button, Modal, ModalBody, ModalContent, ModalFooter, ModalHeader } from "@nextui-org/react";
import { useTranslation } from "@/src/hooks/useTranslation";

const EndConversation = () => {

    //store handler
    const openModalEnd = useHandleConversationStore(state => state.openModalEnd);
    const handleOpenModalEnd = useHandleConversationStore(state => state.actions.handleOpenModalEnd);
    const selectedConversation = useHandleConversationStore(state => state.selectedConversation);
    const { trans } = useTranslation();

    const { endConversationData, getOptionsEnds, loading, setLoading, handleSubmitEndConversation } = useOptionsConversation(selectedConversation);
    const [selectedValue, setSelectedValue] = useState('');

    useEffect(() => {
        if (openModalEnd == true) {
            getOptionsEnds()
            setLoading(false)
        }
    }, [openModalEnd])


    const handleSubmit = async () => {
        setLoading(true)
        if (endConversationData.length > 0) {
            if (selectedValue.trim() == '') {
                setLoading(false)
                toast.error(trans("modal_conversations_end_message_alert_select_option_title"));
                return
            }
            await handleSubmitEndConversation(selectedValue, true)
        } else {
            await handleSubmitEndConversation('', false)
        }

        if (loading == false) {
            handleOpenModalEnd()
        }
    }

    const handleRadioChange = (event: any) => {
        event.stopPropagation();
        setSelectedValue(event.target.value);
    };

    return (
        <>
            <Modal isOpen={openModalEnd} onOpenChange={() => handleOpenModalEnd()} size="lg">

                <ModalContent>
                    {(onClose) => (
                        <>
                            <ModalHeader>
                                {trans("modal_conversations_end_title")} {selectedConversation.sesion}
                            </ModalHeader>
                            <ModalBody>
                                <h6 className="text-sm my-1"><strong>{trans("modal_conversations_end_subtitle")}</strong></h6>

                                <div className="p-2 max-h-96 custom-scroll overflow-y-auto">
                                    {endConversationData.map((item: any, index: number) => (
                                        <div className="form-check m-1 flex flex-row justify-start items-center" onClick={(e) => e.stopPropagation()} key={index}>
                                            <input onChange={(e) => handleRadioChange(e)} className="form-check-input my-0" type="radio" name="endConversation" id={`endConversation-id-${index}`} value={item.idterminar} key={index} />
                                            <label className="form-check-label ml-2" htmlFor={`endConversation-id-${index}`}>
                                                {item.terminar} {item.bot_nombre !== '' && ` - Bot (${item.bot_nombre})`}
                                            </label>
                                        </div>
                                    ))}
                                </div>
                            </ModalBody>
                            <ModalFooter>
                                <Button color="danger" variant="light" isDisabled={loading} onPress={handleOpenModalEnd}>
                                    {trans("modal_conversations_end_button_cancel_title")}
                                </Button>
                                <Button color="primary" isLoading={loading} onPress={handleSubmit}>
                                    {trans("modal_conversations_end_button_send_title")}
                                </Button>
                            </ModalFooter>
                        </>
                    )}
                </ModalContent>
            </Modal>
        </>
    )
}

export default EndConversation